const { moduleInterop } = require('@textlint/module-interop')

module.exports = {
	rules: {
		'no-unmatched-pair': moduleInterop(require('@textlint-rule/textlint-rule-no-unmatched-pair')),
		'abbr-within-parentheses': moduleInterop(require('textlint-rule-abbr-within-parentheses')),
		'apostrophe': moduleInterop(require('textlint-rule-apostrophe')),
		'common-misspellings': moduleInterop(require('textlint-rule-common-misspellings')),
		'diacritics': moduleInterop(require('textlint-rule-diacritics')),
		'doubled-spaces': moduleInterop(require('textlint-rule-doubled-spaces')),
		'en-capitalization': moduleInterop(require('textlint-rule-en-capitalization')),
		'en-max-word-count': moduleInterop(require('textlint-rule-en-max-word-count')),
		'no-dead-link': moduleInterop(require('textlint-rule-no-dead-link')),
		'no-empty-section': moduleInterop(require('textlint-rule-no-empty-section')),
		'no-start-duplicated-conjunction': moduleInterop(require('textlint-rule-no-start-duplicated-conjunction')),
		'terminology': moduleInterop(require('textlint-rule-terminology')),
	},
	rulesConfig: {
		'diacritics': true,
		'apostrophe': true,
		'no-dead-link': true,
		'doubled-spaces': true,
		'no-empty-section': true,
		'common-misspellings': true,
		'abbr-within-parentheses': true,
		'@textlint-rule/no-unmatched-pair': true,
		'no-start-duplicated-conjunction': { interval: 2 },
		'en-max-word-count': { max: 50 },
		'en-capitalization': {
			allowFigures: true,
			allowLists: true,
			allowWords: [
				'bell',
				'jit',
				'jue',
			],
		},
		'terminology': {
			defaultTerms: false,
			terms: [
				'Airbnb',
				'Android',
				'AppleScript',
				'AppVeyor',
				'AVA',
				'BrowserStack',
				'Browsersync',
				'Codecov',
				'CodePen',
				'CodeSandbox',
				'DefinitelyTyped',
				'EditorConfig',
				'ESLint',
				'Github',
				'GraphQL',
				'GraphiQL',
				'iOS',
				'Javascript',
				'JetBrains',
				'jQuery',
				'LinkedIn',
				'Lodash',
				'MacBook',
				'Markdown',
				'OpenType',
				'PayPal',
				'PhpStorm',
				'RubyMine',
				'Sass',
				'SemVer',
				'TypeScript',
				'UglifyJS',
				'Wasm',
				'WebAssembly',
				'WebStorm',
				'WordPress',
				'Youtube',
				[ 'Common[ .]js', 'CommonJS' ],
				[ 'JSDocs?', 'JSDoc' ],
				[ 'Node(?:js)?', 'Node.js' ],
				[ 'React[ .]js', 'React' ],
				[ 'SauceLabs', 'Sauce Labs' ],
				[ 'StackOverflow', 'Stack Overflow' ],
				[ 'styled ?components', 'styled-components' ],
				[ 'HTTP[ /]2(?:\\.0)?', 'HTTP/2' ],
				[ 'OS X', 'macOS' ],
				[ 'Mac ?OS', 'macOS' ],
				[ 'a npm', 'an npm' ],
				'3D',
				[ '3-D', '3D' ],
				'Ajax',
				'API',
				[ 'API[\'’]?s', 'APIs' ],
				'CSS',
				'GIF',
				'HTML',
				'HTTPS',
				'IoT',
				'I/O',
				[ 'I-O', 'I/O' ],
				'JPEG',
				'MIME',
				'OK',
				'PaaS',
				'PDF',
				'PNG',
				'SaaS',
				'URL',
				[ 'URL[\'’]?s', 'URLs' ],
				[ 'an URL', 'a URL' ],
				[ 'wi[- ]?fi', 'Wi-Fi' ],
				'ID',
				[ 'id[\'’]?s', 'IDs' ],
				[ 'backwards compatible', 'backward compatible' ],
				[ 'she or he', 'they' ],
				[ 'she/he', 'they' ],
				[ 'he or she', 'they' ],
				[ 'he/she', 'they' ],
				[ 'his or hers', 'theirs' ],
				[ 'his or her', 'their' ],
				[ 'him or her', 'them' ],
				[ 'him or herself', 'themself' ],
				[ '\\(s\\)he', 'they' ],
				[ 'repo\\b', 'repository' ],
				[ 'auto[- ]complete', 'autocomplete' ],
				[ 'back[- ]end(\\w*)', 'backend$1' ],
				[ 'bug[- ]fix(es)?', 'bugfix$1' ],
				[ 'change[- ]log(s)?', 'changelog$1' ],
				[ 'check[- ]box(es)?', 'checkbox$1' ],
				[ 'code[- ]base(es)?', 'codebase$1' ],
				[ 'co[- ]locate(d?)', 'colocate$1' ],
				[ 'end[- ]point(s)?', 'endpoint$1' ],
				[ 'e[- ]mail(s)?', 'email$1' ],
				[ 'file[- ]name(s)?', 'filename$1' ],
				[ 'front[- ]end(\\w*)', 'frontend$1' ],
				[ 'hack[- ]a[- ]thon(s)?', 'hackathon$1' ],
				[ 'host[- ]name(s)?', 'hostname$1' ],
				[ 'hot[- ]key(s)?', 'hotkey$1' ],
				[ 'life[- ]cycle', 'lifecycle' ],
				[ 'life[- ]stream(s)?', 'lifestream$1' ],
				[ 'lock[- ]file(s)?', 'lockfile$1' ],
				[ 'mark-up', 'markup' ],
				[ 'meta[- ]data', 'metadata' ],
				[ 'micro[- ]service(s)?', 'microservice$1' ],
				[ 'name[- ]space(s)?', 'namespace$1' ],
				[ 'pre[- ]condition(s)?', 'precondition$1' ],
				[ 'pre[- ]defined', 'predefined' ],
				[ 'pre[- ]release(s)?', 'prerelease$1' ],
				[ 're[- ]write', 'rewrite' ],
				[ 'run[- ]time', 'runtime' ],
				[ 'screen[- ]shot(s)?', 'screenshot$1' ],
				[ 'screen[- ]?snap(s)?', 'screenshot$1' ],
				[ 'sub[- ]class((?:es|ing)?)', 'subclass$1' ],
				[ 'sub[- ]tree(s)?', 'subtree$1' ],
				[ 'time[- ]stamp(s)?', 'timestamp$1' ],
				[ 'touch[- ]screen(s)?', 'touchscreen$1' ],
				[ 'user[- ]name(s)?', 'username$1' ],
				[ 'walk[- ]through', 'walkthrough' ],
				[ 'white[- ]space', 'whitespace' ],
				[ 'wild[- ]card(s)?', 'wildcard$1' ],
				[ 'file-?type(s)?', 'file type$1' ],
				[ 'micro-?frontend(s)?', 'micro frontend$1' ],
				[ 'open-?source(ed?)', 'open source$1' ],
				[ 'regexp?(s)?', 'regular expression$1' ],
				[ 'style[- ]guide(s)?', 'styleguide$1' ],
				[ 'Good[- ]byte', 'Goodbyte' ],
				[ 'built ?in', 'built-in' ],
				[ 'client ?side', 'client-side' ],
				[ 'command ?line', 'command-line' ],
				[ 'end ?to ?end', 'end-to-end' ],
				[ 'end[- ]?2[- ]?end', 'end-to-end' ],
				[ 'error ?prone', 'error-prone' ],
				[ 'higher ?order', 'higher-order' ],
				[ 'key[/ ]?value', 'key-value' ],
				[ 'server ?side', 'server-side' ],
				[ 'two ?steps? authentication', 'two-step authentication' ],
				[ 'two ?steps? verification', 'two-step verification' ],
				[ '2 ?steps? authentication', 'two-step authentication' ],
				[ '2 ?steps? verification', 'two-step verification' ],
				[ '3rd[- ]party', 'third-party' ],
				[ 'environemnt(s)?', 'environment$1' ],
				[ 'falsey', 'falsy' ],
			],
		},
	},
}